==> Products.PrintingMailHost-0.2.tar.gz: Products.PrintingMailHost-0.2/Products/PrintingMailHost/Patch.py <==
import logging
from AccessControl import ClassSecurityInfo
from Acquisition import aq_base
from DateTime import DateTime
from Acquisition import aq_inner, aq_parent, aq_base, aq_chain
from Products.Archetypes.utils import shasattr
from Products.CMFCore.utils import getToolByName
from Products.MailHost.MailHost import MailBase

try:
    from Products.SecureMailHost.SecureMailHost import SecureMailBase
    HAS_SMH = True
except ImportError:
    HAS_SMH = False

LOG = logging.getLogger('PrintingMailHost')
PATCH_PREFIX = '_monkey_'

__refresh_module__ = 0

def monkeyPatch(originalClass, patchingClass):
    """Monkey patch original class with attributes from new class
       (Swiped from SpeedPack -- thanks, Christian Heimes!)

    * Takes all attributes and methods except __doc__ and __module__ from patching class
    * Safes original attributes as _monkey_name
    * Overwrites/adds these attributes in original class
    """
    for name, newAttr in patchingClass.__dict__.items():
        # don't overwrite doc or module informations
        if name not in ('__doc__', '__module__'):
            # safe the old attribute as __monkey_name if exists
            # __dict__ doesn't show inherited attributes :/
            orig = getattr(originalClass, name, None)
            if orig:
                stored_orig_name = PATCH_PREFIX + name
                stored_orig = getattr(originalClass, stored_orig_name, None)
                # don't double-patch on refresh!
                if stored_orig is None:
                    setattr(originalClass, stored_orig_name, orig)
            # overwrite or add the new attribute
            setattr(originalClass, name, newAttr)


class PrintingMailHost:
    """MailHost which prints to output."""
    security = ClassSecurityInfo()

    security.declarePrivate( '_send' )
    def _send(self, mfrom, mto, messageText, debug=False):
        """Send the message."""
        print
        print " ---- sending mail ---- "
        print "From:", mfrom
        print "To:", mto
        print messageText
        print " ---- done ---- "
        print


LOG.warn('\n\n******************************************************************************\n\n'
         'Monkey patching MailHosts to print emails to the terminal instead of sending them.\n'
         '\n'
         'NO MAIL WILL BE SENT FROM ZOPE AT ALL!\n'
         '\n'
         'Turn off debug mode or remove PrintingMailHost from the Products directory to turn this off.\n'
         '\n******************************************************************************\n')

monkeyPatch(MailBase, PrintingMailHost)
if HAS_SMH:
    monkeyPatch(SecureMailBase, PrintingMailHost)

==> Products.PrintingMailHost-0.3.tar.gz: Products.PrintingMailHost-0.3/Products/PrintingMailHost/Patch.py <==
import logging
from base64 import decodestring
import email.Parser
from AccessControl import ClassSecurityInfo
from Products.MailHost.MailHost import MailBase

try:
    from Products.SecureMailHost.SecureMailHost import SecureMailBase
    HAS_SMH = True
except ImportError:
    HAS_SMH = False

LOG = logging.getLogger('PrintingMailHost')
PATCH_PREFIX = '_monkey_'

__refresh_module__ = 0

def monkeyPatch(originalClass, patchingClass):
    """Monkey patch original class with attributes from new class
       (Swiped from SpeedPack -- thanks, Christian Heimes!)

    * Takes all attributes and methods except __doc__ and __module__ from patching class
    * Safes original attributes as _monkey_name
    * Overwrites/adds these attributes in original class
    """
    for name, newAttr in patchingClass.__dict__.items():
        # don't overwrite doc or module informations
        if name not in ('__doc__', '__module__'):
            # safe the old attribute as __monkey_name if exists
            # __dict__ doesn't show inherited attributes :/
            orig = getattr(originalClass, name, None)
            if orig:
                stored_orig_name = PATCH_PREFIX + name
                stored_orig = getattr(originalClass, stored_orig_name, None)
                # don't double-patch on refresh!
                if stored_orig is None:
                    setattr(originalClass, stored_orig_name, orig)
            # overwrite or add the new attribute
            setattr(originalClass, name, newAttr)


class PrintingMailHost:
    """MailHost which prints to output."""
    security = ClassSecurityInfo()

    security.declarePrivate( '_send' )
    def _send(self, mfrom, mto, messageText, debug=False):
        """Send the message."""
        if isinstance(messageText, str):
            messageText = email.Parser.Parser().parsestr(messageText)
        base64_note = ""
        print
        print " ---- sending mail ---- "
        print "From:", mfrom
        print "To:", mto
        if messageText.get('Content-Transfer-Encoding') == 'base64':
            base64_note = "NOTE: The email payload was originally base64 " \
                          "encoded.  It was decoded for debug purposes."
            orig_text = messageText.get_payload()
            messageText.set_payload(decodestring(orig_text))
        print messageText
        print " ---- done ---- "
        print
        if base64_note:
            print base64_note
            print


LOG.warn('\n\n******************************************************************************\n\n'
         'Monkey patching MailHosts to print emails to the terminal instead of sending them.\n'
         '\n'
         'NO MAIL WILL BE SENT FROM ZOPE AT ALL!\n'
         '\n'
         'Turn off debug mode or remove PrintingMailHost from the Products directory to turn this off.\n'
         '\n******************************************************************************\n')

monkeyPatch(MailBase, PrintingMailHost)
if HAS_SMH:
    monkeyPatch(SecureMailBase, PrintingMailHost)
